@@ -25,7 +25,7 @@ function is_musl() {
 	fi
 }
 
-curl 'https://zlib.net/zlib-1.2.11.tar.gz' | tar xz
+curl -L 'https://github.com/madler/zlib/archive/refs/tags/v1.2.11.tar.gz' | tar xz
 cd zlib-1.2.11
 is_musl && CC=musl-gcc ./configure || ./configure
 make
